@@ -202,7 +202,8 @@ assert args[2] == 5
 
         # type mismatch
         check('u', [-1], 'convert negative value to unsigned')
-        check('i', ['hello'], 'TypeError: an integer is required')
+        check('i', ['hello'], 'TypeError')
+        check('i', ['hello'], 'integer')
         check('s', [1], 'TypeError: Expected a string')
 
     def test_add_object(self):
@@ -527,7 +528,8 @@ assert args[2] == 5
 
         # type mismatch
         check('u', [-1], 'convert negative value to unsigned')
-        check('i', ['hello'], 'TypeError: an integer is required')
+        check('i', ['hello'], 'TypeError')
+        check('i', ['hello'], 'integer')
         check('s', [1], 'TypeError: Expected a string')
 
     def test_dbus_get_log(self):
