@@ -13,12 +13,15 @@ import unittest
 import shutil
 import sys
 import subprocess
+import tempfile
+import tracemalloc
 
 import dbus
 
 import dbusmock
 
 
+tracemalloc.start(25)
 have_upower = shutil.which('upower')
 
 
@@ -55,11 +58,12 @@ class TestCLI(dbusmock.DBusTestCase):
                                         '--system', 'com.example.Test', '/', 'TestIface'])
         self.wait_for_bus_object('com.example.Test', '/', True)
 
-    def test_template_system(self):
+    def test_template_upower(self):
         self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock',
-                                        '--system', '-t', 'upower'],
+                                        '-t', 'upower'],
                                        stdout=subprocess.PIPE,
                                        universal_newlines=True)
+        # template specifies system bus
         self.wait_for_bus_object('org.freedesktop.UPower', '/org/freedesktop/UPower', True)
 
         # check that it actually ran the template, if we have upower
@@ -72,9 +76,35 @@ class TestCLI(dbusmock.DBusTestCase):
             self.assertTrue('EnumerateDevices' in mock_out or 'GetAll' in mock_out,
                             mock_out)
 
+    def test_template_explicit_system(self):
+        # --system is redundant here, but should not break
+        self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock',
+                                        '--system', '-t', 'upower'],
+                                       stdout=subprocess.PIPE,
+                                       universal_newlines=True)
+        self.wait_for_bus_object('org.freedesktop.UPower', '/org/freedesktop/UPower', True)
+
+    def test_template_override_session(self):
+        # --system is redundant here, but should not break
+        self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock',
+                                        '--session', '-t', 'upower'],
+                                       stdout=subprocess.PIPE,
+                                       universal_newlines=True)
+        self.wait_for_bus_object('org.freedesktop.UPower', '/org/freedesktop/UPower')
+
+    def test_template_conflicting_bus(self):
+        with self.assertRaises(subprocess.CalledProcessError) as cm:
+            subprocess.check_output([sys.executable, '-m', 'dbusmock',
+                                     '--system', '--session', '-t', 'upower'],
+                                    stderr=subprocess.STDOUT,
+                                    universal_newlines=True)
+        err = cm.exception
+        self.assertEqual(err.returncode, 2)
+        self.assertRegex(err.output, '--system.*--session.*exclusive')
+
     def test_template_parameters(self):
         self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock',
-                                        '--system', '-t', 'upower',
+                                        '-t', 'upower',
                                         '-p', '{"DaemonVersion": "0.99.0", "OnBattery": true}'],
                                        stdout=subprocess.PIPE,
                                        universal_newlines=True)
@@ -90,7 +120,7 @@ class TestCLI(dbusmock.DBusTestCase):
     def test_template_parameters_malformed_json(self):
         with self.assertRaises(subprocess.CalledProcessError) as cm:
             subprocess.check_output([sys.executable, '-m', 'dbusmock',
-                                     '--system', '-t', 'upower', '-p',
+                                     '-t', 'upower', '-p',
                                      '{"DaemonVersion: "0.99.0"}'],
                                     stderr=subprocess.STDOUT,
                                     universal_newlines=True)
@@ -101,7 +131,7 @@ class TestCLI(dbusmock.DBusTestCase):
     def test_template_parameters_not_dict(self):
         with self.assertRaises(subprocess.CalledProcessError) as cm:
             subprocess.check_output([sys.executable, '-m', 'dbusmock',
-                                     '--system', '-t', 'upower', '-p',
+                                     '-t', 'upower', '-p',
                                      '"banana"'],
                                     stderr=subprocess.STDOUT,
                                     universal_newlines=True)
@@ -109,6 +139,50 @@ class TestCLI(dbusmock.DBusTestCase):
         self.assertEqual(err.returncode, 2)
         self.assertEqual(err.output, 'JSON parameters must be a dictionary\n')
 
+    def test_template_local(self):
+        with tempfile.NamedTemporaryFile(prefix='answer_', suffix='.py') as my_template:
+            my_template.write(b'''import dbus
+BUS_NAME = 'universe.Ultimate'
+MAIN_OBJ = '/'
+MAIN_IFACE = 'universe.Ultimate'
+SYSTEM_BUS = False
+
+def load(mock, parameters):
+    mock.AddMethods(MAIN_IFACE, [('Answer', '', 'i', 'ret = 42')])
+''')
+            my_template.flush()
+            self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock', '-t', my_template.name],
+                                           stdout=subprocess.PIPE,
+                                           universal_newlines=True)
+            # template specifies session bus
+            self.wait_for_bus_object('universe.Ultimate', '/', False)
+
+        obj = self.session_con.get_object('universe.Ultimate', '/')
+        if_u = dbus.Interface(obj, 'universe.Ultimate')
+        self.assertEqual(if_u.Answer(), 42)
+
+    def test_template_override_system(self):
+        with tempfile.NamedTemporaryFile(prefix='answer_', suffix='.py') as my_template:
+            my_template.write(b'''import dbus
+BUS_NAME = 'universe.Ultimate'
+MAIN_OBJ = '/'
+MAIN_IFACE = 'universe.Ultimate'
+SYSTEM_BUS = False
+
+def load(mock, parameters):
+    mock.AddMethods(MAIN_IFACE, [('Answer', '', 'i', 'ret = 42')])
+''')
+            my_template.flush()
+            self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock', '--system', '-t', my_template.name],
+                                           stdout=subprocess.PIPE,
+                                           universal_newlines=True)
+            # template specifies session bus, but CLI overrides to system
+            self.wait_for_bus_object('universe.Ultimate', '/', True)
+
+        obj = self.system_con.get_object('universe.Ultimate', '/')
+        if_u = dbus.Interface(obj, 'universe.Ultimate')
+        self.assertEqual(if_u.Answer(), 42)
+
     def test_object_manager(self):
         self.p_mock = subprocess.Popen([sys.executable, '-m', 'dbusmock',
                                         '-m', 'com.example.Test', '/', 'TestIface'],
